def infinite_iterator(iterator):
    """Infinite iterator

    :param iterator: iterator
    :type iterator: iterator
    :yield: item from iterator
    :rtype: Any
    """
    while True:
        for item in iterator:
            yield item

            
def property_with_cache(func):
    """Property decorator to cache the result of a property. The result is cached in the attribute of name "_{func.__name__}".

    :param func: function to decorate
    :type func: function
    :return: decorated function
    :rtype: function
    """
    @property
    def decorated_func(self):
        # Get the attribute name
        attr_name = f"_{func.__name__}"
        # Create the attribute if it does not exists
        if not hasattr(self, attr_name) or getattr(self, attr_name) is None:
            setattr(self, attr_name, func(self))
        return getattr(self, attr_name)
    return decorated_func



import unittest

import src.hkkang_utils.string as string_utils


class Test_string_utils(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(Test_string_utils, self).__init__(*args, **kwargs)
    
    def test_multi_space_to_single_space(self):
        pass
    
    def test_is_int(self):
        pass
    
    def test_is_number(self):
        pass


if __name__ == "__main__":
    unittest.main()



import hkkang_utils.file
import hkkang_utils.list
import hkkang_utils.sql
import hkkang_utils.string
import hkkang_utils.tensor
import hkkang_utils.testing
__all__ = ["file", "list", "sql", "string", "tensor", "testing"]